@@ -2,9 +2,10 @@ use strict;
 use warnings;
 package Exception::Reporter::Summarizer::File;
 {
-  $Exception::Reporter::Summarizer::File::VERSION = '0.006';
+  $Exception::Reporter::Summarizer::File::VERSION = '0.007';
 }
 use parent 'Exception::Reporter::Summarizer';
+# ABSTRACT: a summarizer for a File object
 
 
 use File::Basename ();
@@ -41,11 +42,11 @@ __END__
 
 =head1 NAME
 
-Exception::Reporter::Summarizer::File
+Exception::Reporter::Summarizer::File - a summarizer for a File object
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 OVERVIEW
 
